PyDiagram Changelog
===================

Version 0.6
-----------

* Provide manual mode in pydiagram executable.
* Initiate documentation.
* Support keeping history in server mode.
* Improve phase boundary detection.
* Improve removing duplicated simulation jobs.
* Many bug fixes.

Version 0.5
-----------

* Support manually added simulation jobs.
* Improve sync simulation results.
* Small tweaks in plotting mode.
* Many bug fixes.

Version 0.4
-----------

* Provide predictor mode in pydiagram executable.

Version 0.3
-----------

* Provide an executable for general usage.
* Support parsing PolyFTS results.
* Support project configuration file.
* Fix many bugs.
* Fix most of PEP8 violations.

Version 0.2
-----------

* Add I/O interface for loading and dumping .dgm files.
* Add .dgm file format to communicate with other software packages.

Version 0.1
-----------

* First release.

Initiated
---------

* Mar. 16th, 2015
